===============
Django PyNotify
===============


.. image:: https://img.shields.io/pypi/v/django-pynotify.svg
        :target: https://pypi.python.org/pypi/django-pynotify

.. image:: https://img.shields.io/travis/druids/django-pynotify.svg
        :target: https://travis-ci.org/druids/django-pynotify

.. image:: https://readthedocs.org/projects/django-pynotify/badge/?version=latest
        :target: https://django-pynotify.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/druids/django-pynotify/badge.svg?branch=master
        :target: https://coveralls.io/github/druids/django-pynotify?branch=master
        :alt: Code coverage

General purpose notification library for Django.


* Free software: MIT license
* Documentation: https://django-pynotify.readthedocs.io.
* Supported Python versions: 3.6, 3.7, 3.8, 3.9
* Supported Django versions: 2.2, 3.0, 3.1


Features
--------

* Easy integration into project
* Notification templating and translation
* Asynchronous operation

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
